@@ -15,7 +15,7 @@ class ErrorHandler:
         502 : ("E", [3, 3]),
         503 : ("E", [3, 3]),
         504 : ("E", [3, 3]),
-        602 : ("T", []),
+        602 : ("R", [2]),
         800 : ("T", []),
     }
 
