@@ -1,7 +1,8 @@
 from functools import partial
 from inspect import getmembers, isfunction
-from typing import List, Any
+from typing import List, Any, Set, Dict
 from importlib import import_module
+import itertools
 import asyncio
 import pickle
 import re
@@ -27,6 +28,18 @@ def inherit_docstrings(cls):
     return cls
 
 
+def case_combinations(string: str) -> Set[str]:
+    return set(map(''.join, itertools.product(*((c.upper(), c.lower()) for c in string))))
+
+
+def case_insensitive_dict(dic: Dict) -> Dict:
+    new_dic = {}
+    for key, val in dic.items():
+        for ikey in case_combinations(key):
+            new_dic[ikey] = val
+    return new_dic
+
+
 def snakecase(attr: str) -> str:
     '''Convert string to python snakecase.'''
     name = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', attr)
@@ -96,3 +109,8 @@ def bytify(obj):
 def pytify(obj):
     '''Convert a byte string to python object.'''
     return pickle.loads(obj)
+
+
+def dict_key_value_swap(dic: Dict) -> Dict:
+    '''Swap keys and values of a dictionary'''
+    return {v: k for k, v in dic.items()}
