@@ -1,4 +1,4 @@
-from pyot.utils import loop_run
+import asyncio
 from pyot.models import lor
 from syot.models import riot
 from .__core__ import SyotBaseObject
@@ -10,11 +10,11 @@ class SyotBase(SyotBaseObject):
 
 class Card(SyotBase, lor.Card):
     def get(self, **kwargs):
-        return loop_run(super().get(**kwargs))
+        return asyncio.run(super().get(**kwargs))
 
 class Cards(SyotBase, lor.Cards):
     def get(self, **kwargs):
-        return loop_run(super().get(**kwargs))
+        return asyncio.run(super().get(**kwargs))
 
 class Batch(SyotBase, lor.Batch):
     pass
@@ -26,17 +26,23 @@ class Deck(SyotBase, lor.Deck):
 
 class Match(SyotBase, lor.Match):
     def get(self, **kwargs):
-        return loop_run(super().get(**kwargs))
+        return asyncio.run(super().get(**kwargs))
 
 class MatchHistory(SyotBase, lor.MatchHistory):
     def get(self, **kwargs):
-        return loop_run(super().get(**kwargs))
+        return asyncio.run(super().get(**kwargs))
 
 # from .ranked import Leaderboard
 
 class Leaderboard(SyotBase, lor.Leaderboard):
     def get(self, **kwargs):
-        return loop_run(super().get(**kwargs))
+        return asyncio.run(super().get(**kwargs))
+
+# from .status import Status
+
+class Status(SyotBase, lor.Status):
+    def get(self, **kwargs):
+        return asyncio.run(super().get(**kwargs))
 
 
 SyotBase._bridges = {
@@ -47,6 +53,7 @@ SyotBase._bridges = {
     "Match": Match,
     "MatchHistory": MatchHistory,
     "Leaderboard": Leaderboard,
+    "Status": Status,
 }
 
 SyotBase._bridges.update(riot.SyotBase._bridges)
